==> ui-0.2.43.tgz: package/lib/cjs/Radio/Radio.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.composeRef = composeRef;
exports.default = void 0;
exports.fillRef = fillRef;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _filter = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/filter"));
var _forEach = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/for-each"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Radio.styled"));
var _Checkbox = require("../Checkbox/Checkbox.context");
var _Radio2 = _interopRequireWildcard(require("./Radio.context"));
var _classnames = _interopRequireDefault(require("classnames"));
var _Radio3 = require("./Radio.icon");
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
function fillRef(ref, node) {
  if (typeof ref === 'function') {
    ref(node);
  } else if (typeof ref === 'object' && ref && 'current' in ref) {
    // eslint-disable-next-line no-param-reassign
    ref.current = node;
  }
}
function composeRef() {
  for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
    refs[_key] = arguments[_key];
  }
  const refList = (0, _filter.default)(refs).call(refs, ref => ref);
  if (refList.length <= 1) return refList[0];
  return node => (0, _forEach.default)(refs).call(refs, ref => fillRef(ref, node));
}
const InternalRadio = (props, ref) => {
  const groupContext = _react.default.useContext(_Radio2.RadioGroupContext);
  const {
    getPrefixCls,
    direction
  } = _react.default.useContext(_Checkbox.ConfigContext);
  const innerRef = _react.default.useRef();
  const mergedRef = composeRef(ref, innerRef);
  const {
    isFormItemInput
  } = _react.default.useContext(_Checkbox.FormItemInputContext);
  const onChange = e => {
    var _a, _b;
    (_a = props.onChange) === null || _a === void 0 ? void 0 : _a.call(props, e);
    (_b = groupContext === null || groupContext === void 0 ? void 0 : groupContext.onChange) === null || _b === void 0 ? void 0 : _b.call(groupContext, e);
  };
  const {
      prefixCls: customizePrefixCls,
      className,
      children,
      style,
      disabled: customDisabled
    } = props,
    restProps = __rest(props, ["prefixCls", "className", "children", "style", "disabled"]);
  const prefixCls = getPrefixCls('radio', customizePrefixCls);
  const radioProps = (0, _assign.default)({}, restProps);
  const disabled = _react.default.useContext(_Radio2.default);
  radioProps.disabled = customDisabled || disabled;
  if (groupContext) {
    radioProps.name = groupContext.name;
    radioProps.onChange = onChange;
    radioProps.checked = props.value === groupContext.value;
    radioProps.disabled = radioProps.disabled || groupContext.disabled;
  }
  const wrapperClassString = (0, _classnames.default)(`${prefixCls}-wrapper`, {
    [`${prefixCls}-wrapper-checked`]: radioProps.checked,
    [`${prefixCls}-wrapper-disabled`]: radioProps.disabled,
    [`${prefixCls}-wrapper-rtl`]: direction === 'rtl',
    [`${prefixCls}-wrapper-in-form-item`]: isFormItemInput
  }, className);
  return (0, _jsxRuntime.jsxs)(Styled.DSRadioWrapper, (0, _assign.default)({
    className: wrapperClassString,
    style: style,
    onMouseEnter: props.onMouseEnter,
    onMouseLeave: props.onMouseLeave,
    "$disabled": radioProps.disabled,
    "$checked": !!radioProps.defaultChecked || !!radioProps.checked
  }, {
    children: [(0, _jsxRuntime.jsx)(Styled.NURadio, (0, _assign.default)({}, radioProps, {
      type: "radio",
      prefixCls: prefixCls,
      ref: mergedRef
    })), (0, _jsxRuntime.jsx)(_Radio3.RadioIconContainer, {
      checked: !!radioProps.defaultChecked || !!radioProps.checked,
      disabled: !!radioProps.disabled
    }), children !== undefined && (0, _jsxRuntime.jsx)(Styled.Span, {
      children: children
    })]
  }));
};
const Radio = /*#__PURE__*/_react.default.forwardRef(InternalRadio);
Radio.displayName = 'Radio';
var _default = Radio;
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/Radio/Radio.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.composeRef = composeRef;
exports.default = void 0;
exports.fillRef = fillRef;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _filter = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/filter"));
var _forEach = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/for-each"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Radio.styled"));
var _Checkbox = require("../Checkbox/Checkbox.context");
var _Radio2 = _interopRequireWildcard(require("./Radio.context"));
var _classnames = _interopRequireDefault(require("classnames"));
var _Radio3 = require("./Radio.icon");
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
function fillRef(ref, node) {
  if (typeof ref === 'function') {
    ref(node);
  } else if (typeof ref === 'object' && ref && 'current' in ref) {
    // eslint-disable-next-line no-param-reassign
    ref.current = node;
  }
}
function composeRef() {
  for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
    refs[_key] = arguments[_key];
  }
  const refList = (0, _filter.default)(refs).call(refs, ref => ref);
  if (refList.length <= 1) return refList[0];
  return node => (0, _forEach.default)(refs).call(refs, ref => fillRef(ref, node));
}
const InternalRadio = (props, ref) => {
  const groupContext = _react.default.useContext(_Radio2.RadioGroupContext);
  const {
    getPrefixCls,
    direction
  } = _react.default.useContext(_Checkbox.ConfigContext);
  const innerRef = _react.default.useRef();
  const mergedRef = composeRef(ref, innerRef);
  const {
    isFormItemInput
  } = _react.default.useContext(_Checkbox.FormItemInputContext);
  const onChange = e => {
    var _a, _b;
    (_a = props.onChange) === null || _a === void 0 ? void 0 : _a.call(props, e);
    (_b = groupContext === null || groupContext === void 0 ? void 0 : groupContext.onChange) === null || _b === void 0 ? void 0 : _b.call(groupContext, e);
  };
  const {
      prefixCls: customizePrefixCls,
      className,
      children,
      style,
      disabled: customDisabled
    } = props,
    restProps = __rest(props, ["prefixCls", "className", "children", "style", "disabled"]);
  const prefixCls = getPrefixCls('radio', customizePrefixCls);
  const radioProps = (0, _assign.default)({}, restProps);
  const disabled = _react.default.useContext(_Radio2.default);
  radioProps.disabled = customDisabled || disabled;
  if (groupContext) {
    radioProps.name = groupContext.name;
    radioProps.onChange = onChange;
    radioProps.checked = props.value === groupContext.value;
    radioProps.disabled = radioProps.disabled || groupContext.disabled;
  }
  const wrapperClassString = (0, _classnames.default)(`${prefixCls}-wrapper`, {
    [`${prefixCls}-wrapper-checked`]: radioProps.checked,
    [`${prefixCls}-wrapper-disabled`]: radioProps.disabled,
    [`${prefixCls}-wrapper-rtl`]: direction === 'rtl',
    [`${prefixCls}-wrapper-in-form-item`]: isFormItemInput
  }, className);
  return (0, _jsxRuntime.jsxs)(Styled.DSRadioWrapper, (0, _assign.default)({
    className: wrapperClassString,
    style: style,
    onMouseEnter: props.onMouseEnter,
    onMouseLeave: props.onMouseLeave,
    "$disabled": radioProps.disabled,
    "$checked": !!radioProps.defaultChecked || !!radioProps.checked
  }, {
    children: [(0, _jsxRuntime.jsx)(Styled.NURadio, (0, _assign.default)({}, radioProps, {
      type: "radio",
      prefixCls: prefixCls,
      ref: mergedRef
    })), (0, _jsxRuntime.jsx)(_Radio3.RadioIconContainer, {
      checked: !!radioProps.defaultChecked || !!radioProps.checked,
      disabled: !!radioProps.disabled
    }), children !== undefined && (0, _jsxRuntime.jsx)(Styled.Span, {
      children: children
    })]
  }));
};
const Radio = /*#__PURE__*/_react.default.forwardRef(InternalRadio);
Radio.displayName = 'Radio';
var _default = exports.default = Radio;
